@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from simplemodels.exceptions import SimpleFieldValidationError
+from simplemodels.exceptions import RequiredValidationError
 from simplemodels.fields import SimpleField
 
 
@@ -8,7 +8,7 @@ class AttributeDict(dict):
     """Dict wrapper with access to keys via attributes"""
 
     def __getattr__(self, item):
-        # not override system methods like __deepcopy__
+        # do not override system methods like __deepcopy__
         if item.startswith('__') and item.endswith('__'):
             return super(AttributeDict, self).__getattr__(self, item)
 
@@ -33,12 +33,12 @@ class SimpleEmbeddedMeta(type):
         :return: new class
         """
 
-        _fields = []
+        _fields = {}
         _required_fields = []
 
         for obj_name, obj in dct.items():
             if isinstance(obj, SimpleField):
-                _fields.append(obj_name)
+                _fields[obj_name] = obj
                 if obj.required:
                     _required_fields.append(obj_name)
 
@@ -46,7 +46,7 @@ class SimpleEmbeddedMeta(type):
                 if isinstance(obj, SimpleField):
                     obj._name = obj_name
 
-        dct['_fields'] = tuple(_fields)
+        dct['_fields'] = _fields
         dct['_required_fields'] = tuple(_required_fields)
 
         return super(SimpleEmbeddedMeta, mcs).__new__(mcs, name, parents, dct)
@@ -60,24 +60,30 @@ class DictEmbeddedDocument(AttributeDict):
 
     def __init__(self, **kwargs):
         super(DictEmbeddedDocument, self).__init__(**kwargs)
-        for field_name in self._fields:
+        cls = type(self)
+        errors = []
+
+        for field_name, obj in self._fields.items():
             if field_name in kwargs:
-                setattr(self, field_name, kwargs[field_name])
+                from simplemodels.validators import get_validator
+                value = get_validator(obj.type).validate(kwargs[field_name])
+                setattr(self, field_name, value)
             else:
                 # very tricky here -- look at descriptor SimpleField
                 # this trick need for init default structure representation like
                 # Document() -> {'field_1': <value OR default value>, ...}
                 setattr(self, field_name, getattr(self, field_name))
 
-        cls = type(self)
-        for field_name in cls._required_fields:
-            # field_obj = type(getattr(obj, field_name)).__dict__[field_name]
-            # field_obj.validate()
-            if not getattr(self, field_name):
-                raise SimpleFieldValidationError(
-                    "Field '{}' is required for {}".format(
-                        field_name, cls.__name__)
-                )
+            # Check for require
+            if field_name in cls._required_fields:
+                if not getattr(self, field_name):
+                    errors.append(
+                        "Field '{}' is required for {}".format(
+                            field_name, cls.__name__)
+                    )
+
+        if errors:
+            raise RequiredValidationError(str(errors))
 
     @classmethod
     def get_instance(cls, **kwargs):
